import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split, GridSearchCV
from sklearn.svm import SVC
from sklearn.preprocessing import MinMaxScaler

randomState = 9
df = pd.read_csv('data_name.csv')

y = df['class'].values
x = df.drop(['class'], axis=1)
x = x.values

# Data Preprocessing
scaler = MinMaxScaler()
x = scaler.fit_transform(x)

x_train, x_test, y_train, y_test = train_test_split(x, y, test_size=0.2, random_state=randomState)

# SVM algorithm implement
param_grid = {'C': [0.001, 0.01, 0.1, 1, 10, 100], 'gamma': [0.001, 0.01, 0.1, 1, 10, 100]}
grid_search = GridSearchCV(SVC(), param_grid, return_train_score=True, cv=10)
grid_search.fit(x_train, y_train)

print("test set score : {}".format(grid_search.score(x_test, y_test)))
print("best parameters : {}".format(grid_search.best_params_))
print("best score : {}".format(grid_search.best_score_))
results = pd.DataFrame(grid_search.cv_results_)

scores = np.array(results.mean_test_score.sort_values(ascending=False)).reshape(6, 6)
fig, ax = plt.subplots()
im = ax.imshow(scores, cmap='PiYG')
cbar = ax.figure.colorbar(im, ax=ax)
cbar.ax.set_ylabel(ylabel="Accuracy", rotation=-90, va="center")
ax.set_xticks(np.arange(len(set(results.param_gamma))))
ax.set_yticks(np.arange(len(set(results.param_C))))

ax.set_yticklabels(param_grid['C'])
for i in range(len(param_grid['C'])):
    for j in range(len(param_grid['gamma'])):
        text = ax.text(j, i, np.round(scores[i, j], 2), ha='center', va='center', color='k')

ax.set_xlabel("gamma")
ax.set_ylabel("c")
plt.savefig('data_name.png')
